@@ -79,6 +79,7 @@ import com.google.gwt.user.client.ui.Widget;
  * Create metadata form for ckan product.
  * 
  * @author Costantino Perciante at ISTI-CNR (costantino.perciante@isti.cnr.it)
+ * @author updated by Francesco Mangiacrapa at ISTI-CNR
  */
 public class CreateDatasetForm extends Composite {
 
@@ -263,6 +264,7 @@ public class CreateDatasetForm extends Composite {
 	// error/info messages
 	protected static final String ERROR_PRODUCT_CREATION = "There was an error while trying to publish your item.";
 	protected static final String PRODUCT_CREATED_OK = "Item correctly published!";
+	protected static final String PRODUCT_SUBMITTED_FOR_REVIEW_OK = "Item correctly submitted for review!";
 	private static final String TRYING_TO_CREATE_PRODUCT = "Trying to publish the item, please wait...";
 	protected static final String MISSING_PUBLISH_RIGHTS = "It seems you are not authorized to publish on catalogue. Request it to the VRE manager or the portal administrator.";
 
@@ -303,6 +305,9 @@ public class CreateDatasetForm extends Composite {
 
 	private FlowPanel alertPanel = new FlowPanel();
 
+	// Feature #28746
+	private Boolean catalogueModerated = false;
+
 	/**
 	 * Invoked in the most general case
 	 * 
@@ -393,7 +398,8 @@ public class CreateDatasetForm extends Composite {
 			listOfSteps = Arrays.asList("Edit Common Metadata", "Select Item Resources",
 					"Edit Item Specific Metadata & Publish");
 		} else {
-			listOfSteps = Arrays.asList("Edit Common Metadata", "Edit Item Specific Metadata & Publish", "Add Resources");
+			listOfSteps = Arrays.asList("Edit Common Metadata", "Edit Item Specific Metadata & Publish",
+					"Add Resources");
 		}
 
 		this.wizCreator = new WizardCreator(listOfSteps);
@@ -1234,7 +1240,11 @@ public class CreateDatasetForm extends Composite {
 
 						final String datasetUrl = createdDatasetBean.getSource();
 
-						alertOnCreate(PRODUCT_CREATED_OK, false, AlertType.SUCCESS, false);
+						String successMsg = catalogueModerated != null && catalogueModerated
+								? PRODUCT_SUBMITTED_FOR_REVIEW_OK
+								: PRODUCT_CREATED_OK;
+
+						alertOnCreate(successMsg, false, AlertType.SUCCESS, false);
 
 						try {
 							// disable dataset fields
@@ -1617,21 +1627,6 @@ public class CreateDatasetForm extends Composite {
 			resourcesSelectByWEMainPanel.freeze();
 	}
 
-//	/**
-//	 * change alert block behavior.
-//	 * 
-//	 * @param textToShow
-//	 * @param type
-//	 * @param visible
-//	 */
-//	private void setAlertBlock(String textToShow, AlertType type, boolean visible) {
-//
-//		infoBlock.setText(textToShow);
-//		infoBlock.setType(type);
-//		infoBlock.setVisible(visible);
-//
-//	}
-
 	/**
 	 * change alert block behavior.
 	 *
@@ -1721,4 +1716,18 @@ public class CreateDatasetForm extends Composite {
 						|| receivedBean.getResourceRoot().getChildrenSize() == 0);
 
 	}
+
+	/**
+	 * Checks if is catalogue moderated.
+	 *
+	 * @return the boolean
+	 */
+	public Boolean isCatalogueModerated() {
+		return catalogueModerated;
+	}
+
+	public void setCatalogueModerated(Boolean isCatalogueModerated) {
+		this.catalogueModerated = isCatalogueModerated;
+	}
+
 }
\ No newline at end of file
